@@ -2,16 +2,20 @@ import base64
 import hashlib
 import hmac
 import json
+import logging
 import time
 import uuid
 from typing import Any, Dict, List, Literal, Optional, Union
 
 import httpx
 
+logger = logging.getLogger(__name__)
+
 from .types import (
+    AcceptUser,
     Invitation,
     InvitationTarget,
-    JwtPayload,
+    User,
     VortexApiError,
 )
 
@@ -39,21 +43,30 @@ class Vortex:
         self._client = httpx.AsyncClient()
         self._sync_client = httpx.Client()
 
-    def generate_jwt(self, payload: Union[JwtPayload, Dict]) -> str:
+    def generate_jwt(self, user: Union[User, Dict], **extra: Any) -> str:
         """
-        Generate a JWT token for the given payload matching Node.js SDK implementation
+        Generate a JWT token for a user
 
         Args:
-            payload: JWT payload containing user_id, identifiers, groups, and role
+            user: User object or dict with 'id', 'email', and optional 'admin_scopes'
+            **extra: Additional properties to include in JWT payload
 
         Returns:
             JWT token string
 
         Raises:
-            ValueError: If API key format is invalid
+            ValueError: If API key format is invalid or required fields are missing
+
+        Example:
+            user = {'id': 'user-123', 'email': 'user@example.com', 'admin_scopes': ['autojoin']}
+            jwt = vortex.generate_jwt(user=user)
+
+            # With additional properties
+            jwt = vortex.generate_jwt(user=user, role='admin', department='Engineering')
         """
-        if isinstance(payload, dict):
-            payload = JwtPayload(**payload)
+        # Convert dict to User if needed
+        if isinstance(user, dict):
+            user = User(**user)
 
         # Parse API key (format: VRTX.base64url(uuid).key)
         parts = self.api_key.split(".")
@@ -94,30 +107,24 @@ class Vortex:
             "kid": kid,
         }
 
-        # Serialize identifiers
-        identifiers_list = [
-            {"type": id.type, "value": id.value} for id in payload.identifiers
-        ]
-
-        # Serialize groups
-        groups_list = None
-        if payload.groups is not None:
-            groups_list = [
-                group.model_dump(by_alias=True, exclude_none=True)
-                for group in payload.groups
-            ]
-
+        # Build JWT payload
         jwt_payload: Dict[str, Any] = {
-            "userId": payload.user_id,
-            "groups": groups_list,
-            "role": payload.role,
+            "userId": user.id,
+            "userEmail": user.email,
             "expires": expires,
-            "identifiers": identifiers_list,
         }
 
-        # Add attributes if provided
-        if hasattr(payload, "attributes") and payload.attributes:
-            jwt_payload["attributes"] = payload.attributes
+        # Add adminScopes if present
+        if user.admin_scopes:
+            jwt_payload["adminScopes"] = user.admin_scopes
+
+        # Add any additional properties from user.model_extra
+        if hasattr(user, "model_extra") and user.model_extra:
+            jwt_payload.update(user.model_extra)
+
+        # Add any additional properties from **extra
+        if extra:
+            jwt_payload.update(extra)
 
         # Step 3: Base64URL encode (without padding)
         header_json = json.dumps(header, separators=(",", ":"))
@@ -184,6 +191,10 @@ class Vortex:
 
                 raise VortexApiError(error_message, response.status_code)
 
+            # Handle empty responses (e.g., DELETE requests may return 204 or empty 200)
+            if response.status_code == 204 or not response.content:
+                return {}  # type: ignore[return-value]
+
             return response.json()  # type: ignore[no-any-return]
 
         except httpx.RequestError as e:
@@ -237,6 +248,10 @@ class Vortex:
 
                 raise VortexApiError(error_message, response.status_code)
 
+            # Handle empty responses (e.g., DELETE requests may return 204 or empty 200)
+            if response.status_code == 204 or not response.content:
+                return {}  # type: ignore[return-value]
+
             return response.json()  # type: ignore[no-any-return]
 
         except httpx.RequestError as e:
@@ -260,7 +275,7 @@ class Vortex:
         params = {"targetType": target_type, "targetValue": target_value}
 
         response = await self._vortex_api_request(
-            "GET", "/invitations/by-target", params=params
+            "GET", "/invitations", params=params
         )
         return [Invitation(**inv) for inv in response.get("invitations", [])]
 
@@ -282,7 +297,7 @@ class Vortex:
         params = {"targetType": target_type, "targetValue": target_value}
 
         response = self._vortex_api_request_sync(
-            "GET", "/invitations/by-target", params=params
+            "GET", "/invitations", params=params
         )
         return [Invitation(**inv) for inv in response.get("invitations", [])]
 
@@ -315,48 +330,188 @@ class Vortex:
         return Invitation(**response)
 
     async def accept_invitations(
-        self, invitation_ids: List[str], target: Union[InvitationTarget, Dict[str, str]]
+        self,
+        invitation_ids: List[str],
+        user_or_target: Union[AcceptUser, InvitationTarget, Dict[str, Any], List[Union[InvitationTarget, Dict[str, str]]]],
     ) -> Dict:
         """
-        Accept multiple invitations
+        Accept multiple invitations using the new User format (preferred)
 
         Args:
             invitation_ids: List of invitation IDs to accept
-            target: Target information (type and value)
+            user_or_target: User object with email/phone/name (preferred) OR legacy target format (deprecated)
 
         Returns:
             API response
-        """
-        target_obj: InvitationTarget
-        if isinstance(target, dict):
-            target_obj = InvitationTarget(**target)  # type: ignore[arg-type]
-        else:
-            target_obj = target
 
-        data = {"invitationIds": invitation_ids, "target": target_obj.model_dump()}
+        Example (new format):
+            user = AcceptUser(email="user@example.com", name="John Doe")
+            result = await client.accept_invitations(["inv-123"], user)
+
+        Example (legacy format - deprecated):
+            target = InvitationTarget(type="email", value="user@example.com")
+            result = await client.accept_invitations(["inv-123"], target)
+        """
+        # Check if it's a list of targets (legacy format with multiple targets)
+        if isinstance(user_or_target, list):
+            logger.warning(
+                "[Vortex SDK] DEPRECATED: Passing a list of targets is deprecated. "
+                "Use the AcceptUser format and call once per user instead."
+            )
+            if not user_or_target:
+                raise ValueError("No targets provided")
+
+            last_result = None
+            last_exception = None
+
+            for target in user_or_target:
+                try:
+                    last_result = await self.accept_invitations(invitation_ids, target)
+                except Exception as e:
+                    last_exception = e
+
+            if last_exception:
+                raise last_exception
+
+            return last_result or {}
+
+        # Check if it's a legacy InvitationTarget
+        is_legacy_target = isinstance(user_or_target, InvitationTarget) or (
+            isinstance(user_or_target, dict)
+            and "type" in user_or_target
+            and "value" in user_or_target
+        )
+
+        if is_legacy_target:
+            logger.warning(
+                "[Vortex SDK] DEPRECATED: Passing an InvitationTarget is deprecated. "
+                "Use the AcceptUser format instead: AcceptUser(email='user@example.com')"
+            )
+
+            # Convert target to User format
+            if isinstance(user_or_target, InvitationTarget):
+                target_type = user_or_target.type
+                target_value = user_or_target.value
+            else:
+                target_type = user_or_target["type"]
+                target_value = user_or_target["value"]
+
+            user = AcceptUser()
+            if target_type == "email":
+                user.email = target_value
+            elif target_type in ("sms", "phoneNumber"):
+                user.phone = target_value
+            else:
+                # For other types, try to use as email
+                user.email = target_value
+
+            # Recursively call with User format
+            return await self.accept_invitations(invitation_ids, user)
+
+        # New User format
+        if isinstance(user_or_target, dict):
+            user = AcceptUser(**user_or_target)
+        else:
+            user = user_or_target
+
+        # Validate that either email or phone is provided
+        if not user.email and not user.phone:
+            raise ValueError("User must have either email or phone")
+
+        data = {"invitationIds": invitation_ids, "user": user.model_dump(exclude_none=True)}
 
         return await self._vortex_api_request("POST", "/invitations/accept", data=data)
 
     def accept_invitations_sync(
-        self, invitation_ids: List[str], target: Union[InvitationTarget, Dict[str, str]]
+        self,
+        invitation_ids: List[str],
+        user_or_target: Union[AcceptUser, InvitationTarget, Dict[str, Any], List[Union[InvitationTarget, Dict[str, str]]]],
     ) -> Dict:
         """
-        Accept multiple invitations (synchronous)
+        Accept multiple invitations using the new User format (synchronous version)
 
         Args:
             invitation_ids: List of invitation IDs to accept
-            target: Target information (type and value)
+            user_or_target: User object with email/phone/name (preferred) OR legacy target format (deprecated)
 
         Returns:
             API response
-        """
-        target_obj: InvitationTarget
-        if isinstance(target, dict):
-            target_obj = InvitationTarget(**target)  # type: ignore[arg-type]
-        else:
-            target_obj = target
 
-        data = {"invitationIds": invitation_ids, "target": target_obj.model_dump()}
+        Example (new format):
+            user = AcceptUser(email="user@example.com", name="John Doe")
+            result = client.accept_invitations_sync(["inv-123"], user)
+
+        Example (legacy format - deprecated):
+            target = InvitationTarget(type="email", value="user@example.com")
+            result = client.accept_invitations_sync(["inv-123"], target)
+        """
+        # Check if it's a list of targets (legacy format with multiple targets)
+        if isinstance(user_or_target, list):
+            logger.warning(
+                "[Vortex SDK] DEPRECATED: Passing a list of targets is deprecated. "
+                "Use the AcceptUser format and call once per user instead."
+            )
+            if not user_or_target:
+                raise ValueError("No targets provided")
+
+            last_result = None
+            last_exception = None
+
+            for target in user_or_target:
+                try:
+                    last_result = self.accept_invitations_sync(invitation_ids, target)
+                except Exception as e:
+                    last_exception = e
+
+            if last_exception:
+                raise last_exception
+
+            return last_result or {}
+
+        # Check if it's a legacy InvitationTarget
+        is_legacy_target = isinstance(user_or_target, InvitationTarget) or (
+            isinstance(user_or_target, dict)
+            and "type" in user_or_target
+            and "value" in user_or_target
+        )
+
+        if is_legacy_target:
+            logger.warning(
+                "[Vortex SDK] DEPRECATED: Passing an InvitationTarget is deprecated. "
+                "Use the AcceptUser format instead: AcceptUser(email='user@example.com')"
+            )
+
+            # Convert target to User format
+            if isinstance(user_or_target, InvitationTarget):
+                target_type = user_or_target.type
+                target_value = user_or_target.value
+            else:
+                target_type = user_or_target["type"]
+                target_value = user_or_target["value"]
+
+            user = AcceptUser()
+            if target_type == "email":
+                user.email = target_value
+            elif target_type in ("sms", "phoneNumber"):
+                user.phone = target_value
+            else:
+                # For other types, try to use as email
+                user.email = target_value
+
+            # Recursively call with User format
+            return self.accept_invitations_sync(invitation_ids, user)
+
+        # New User format
+        if isinstance(user_or_target, dict):
+            user = AcceptUser(**user_or_target)
+        else:
+            user = user_or_target
+
+        # Validate that either email or phone is provided
+        if not user.email and not user.phone:
+            raise ValueError("User must have either email or phone")
+
+        data = {"invitationIds": invitation_ids, "user": user.model_dump(exclude_none=True)}
 
         return self._vortex_api_request_sync("POST", "/invitations/accept", data=data)
 
